@@ -56,6 +56,15 @@ class DiscriminatorBase(nn.Module, WithRegister["DiscriminatorBase"]):
         return DiscriminatorOutput(logits, cond_logits)
 
 
+def weights_init(m: nn.Module) -> None:
+    classname = m.__class__.__name__
+    if classname.find("Conv") != -1:
+        nn.init.normal_(m.weight.data, 0.0, 0.02)
+    elif classname.find("BatchNorm") != -1:
+        nn.init.normal_(m.weight.data, 1.0, 0.02)
+        nn.init.constant_(m.bias.data, 0)
+
+
 @DiscriminatorBase.register("basic")
 class NLayerDiscriminator(DiscriminatorBase):
     def __init__(
@@ -78,10 +87,11 @@ class NLayerDiscriminator(DiscriminatorBase):
                 kernel_size=4,
                 stride=2,
                 padding=1,
-                bias=False,
+                bias=True,
             ),
             nn.LeakyReLU(0.2, inplace=True),
         ]
+        use_bias = norm_type != "batch"
         nc_multiplier = 1
         for i in range(1, num_layers):
             nc_multiplier_prev = nc_multiplier
@@ -91,8 +101,8 @@ class NLayerDiscriminator(DiscriminatorBase):
                     start_channels * nc_multiplier_prev,
                     start_channels * nc_multiplier,
                     4,
-                    2,
-                    bias=False,
+                    1 if i == num_layers - 1 else 2,
+                    bias=use_bias,
                     padding=1,
                     norm_type=norm_type,
                     activation=nn.LeakyReLU(0.2, inplace=True),
@@ -107,9 +117,12 @@ class NLayerDiscriminator(DiscriminatorBase):
             kernel_size=4,
             padding=1,
             stride=1,
-            bias=False,
+            bias=True,
         )
+        # conditional
         self.generate_cond(out_channels)
+        # initialize
+        self.apply(weights_init)
 
 
 @DiscriminatorBase.register("multi_scale")
@@ -141,6 +154,7 @@ class MultiScaleDiscriminator(DiscriminatorBase):
         )
         nets = [self._make() for _ in range(num_scales)]
         self.discriminators = nn.ModuleList(nets)
+        self.apply(weights_init)
 
     def _make(self) -> nn.Sequential:
         in_nc = self.in_channels
